What is the future for :mod:`jnrbase`?
======================================

Where things stand :abbr:`now (2020-02-13)`:

I largely consider :mod:`jnrbase` “done”, and don’t expect any significant
changes.  It will, however, be maintained indefinitely.
